@@ -7,7 +7,7 @@
  */
 
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+#include <chromium-bsu-config.h>
 #endif
 
 #include "gettext.h"
@@ -23,9 +23,16 @@
 #include <cstdio>
 #include <cstdlib>
 #include <cstring>
+#include <ctime>
+
+#ifdef HAVE_LOCALE_H
+#include <locale.h>
+#endif
 
 HiScore	*HiScore::instance = 0;
 
+static const char* header = "# Chromium B.S.U. high scores file: skill rank score date time(UTC) name (do not remove this comment line)\n";
+
 /**
  * initialize variables, then read high score file
  */
@@ -198,10 +205,36 @@ bool HiScore::saveFile()
 	file = fopen(getFileName(), "w");
 	if(file)
 	{
-		fwrite(hiScore,        sizeof(double), 10*HI_SCORE_HIST, file);
-		fwrite(hiScoreName, 64*sizeof(char),   10*HI_SCORE_HIST, file);
-		fwrite(hiScoreDate,    sizeof(time_t), 10*HI_SCORE_HIST, file);
+#ifdef HAVE_LOCALE_H
+		char* locale = setlocale(LC_NUMERIC,"C");
+#endif
+		struct tm* time;
+		int i,j;
+		fprintf(file, "%s", header);
+		for(i = 0; i < 10; i++)
+		{
+			for(j = 0; j < HI_SCORE_HIST; j++)
+			{
+				time = gmtime(&hiScoreDate[i][j]);
+				if( time != NULL ){
+					fprintf(file, 
+					        "%d %d %lf %04d-%02d-%02d %02d:%02d:%02d %s\n",
+					        i, j, 
+					        hiScore[i][j],
+					        1900+time->tm_year,
+					        1+time->tm_mon,
+					        time->tm_mday,
+					        time->tm_hour,
+					        time->tm_min,
+					        time->tm_sec,
+					        hiScoreName[i][j]);
+				}
+			}
+		}
 		fclose(file);
+#ifdef HAVE_LOCALE_H
+		setlocale(LC_NUMERIC,locale);
+#endif
 	}
 	else
 	{
@@ -226,10 +259,75 @@ bool HiScore::readFile()
 	file = fopen(fileName, "r");
 	if(file)
 	{
-		fread(hiScore,        sizeof(double), 10*HI_SCORE_HIST, file);
-		fread(hiScoreName, 64*sizeof(char),   10*HI_SCORE_HIST, file);
-		fread(hiScoreDate,    sizeof(time_t), 10*HI_SCORE_HIST, file);
-		fclose(file);
+		int chr = fgetc(file);
+		if( EOF != chr ){
+			fseek(file, 0L, SEEK_SET);
+			if( '#' == chr ){
+				// Save and reset locale/timezone info
+#ifdef HAVE_LOCALE_H
+				char* locale = setlocale(LC_NUMERIC,"C");
+#endif
+				char *tz = getenv("TZ");
+				setenv("TZ", "", 1);
+				tzset();
+
+				// Discard the comment line
+				fscanf(file,"%*[^\n]");
+
+				char name[100];
+				struct tm time;
+				int i, j;
+				double score;
+				int fields;
+				do{
+					i = j = -1;
+					memset(&time,0,sizeof(time));
+					fields = fscanf(file,
+					                "%d %d %lf %d-%d-%d %d:%d:%d %99s%*[^\n]",
+					                &i, &j,
+					                &score,
+					                &time.tm_year,
+					                &time.tm_mon,
+					                &time.tm_mday,
+					                &time.tm_hour,
+					                &time.tm_min,
+					                &time.tm_sec,
+					                name);
+					if( fields == 10 && i >=0 && i < 10 && j >= 0 && j < HI_SCORE_HIST ){
+						hiScore[i][j] = score;
+						time.tm_year -= 1900;
+						time.tm_mon--;
+						hiScoreDate[i][j] = mktime(&time);
+						strncpy(hiScoreName[i][j], name, 99);
+						hiScoreName[i][j][99] = '\0';
+					}
+				} while( fields != EOF );
+				fclose(file);
+
+				// Reset locale/timezone info
+#ifdef HAVE_LOCALE_H
+				setlocale(LC_NUMERIC,locale);
+#endif
+				if (tz) setenv("TZ", tz, 1);
+				else unsetenv("TZ");
+				tzset();
+
+			} else {
+				// Nasty old memory dump format
+				fread(hiScore,        sizeof(double), 10*HI_SCORE_HIST, file);
+				fread(hiScoreName, 64*sizeof(char),   10*HI_SCORE_HIST, file);
+				fread(hiScoreDate,    sizeof(time_t), 10*HI_SCORE_HIST, file);
+				fclose(file);
+				// Resave the file in plain text format
+				saveFile();
+			}
+		}
+		else 
+		{
+			Config* config = Config::instance();
+			if( config->debug() ) fprintf(stderr, _("WARNING: empty score file (%s)\n"), getFileName());
+			retVal = false;
+		}
 	}
 	else
 	{
