@@ -7,7 +7,7 @@
  */
 
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+#include <chromium-bsu-config.h>
 #endif
 
 #include "gettext.h"
@@ -26,7 +26,7 @@
 
 #include "compatibility.h"
 
-#ifdef HAVE_APPLE_OPENGL_FRAMEWORK
+#if defined(HAVE_APPLE_OPENGL_FRAMEWORK) || (defined(HAVE_OPENGL_GL_H) && defined(HAVE_OPENGL_GLU_H))
 #include <OpenGL/gl.h>
 #include <OpenGL/glu.h>
 #else
@@ -54,6 +54,7 @@ MainSDL::MainSDL(int argc, char **argv)
 	fire = 0;
 	xjoy = yjoy = xjNow = yjNow = 0;
 	adjCount = 0;
+	key_speed_x = key_speed_y = 0;
 	
 	Uint32 initOpts;
 	
@@ -149,6 +150,7 @@ bool MainSDL::run()
 	Uint32 start_time	= 0; 
 	Uint32 now_time		= 0; 
 	Uint32 last_time	= 0;
+	key_speed_x  = key_speed_y = 0.0;
 	int done = 0;
 	int frames;
 
@@ -192,6 +194,7 @@ bool MainSDL::run()
 			done = this->process(&event);
 		}
 		this->joystickMove();
+		this->keyMove();
 		++frames;
 		
 		game->frame++;
