@@ -7,7 +7,7 @@
  */
 
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+#include <chromium-bsu-config.h>
 #endif
 
 #include "gettext.h"
@@ -20,7 +20,7 @@
 
 #include "compatibility.h"
 
-#ifdef HAVE_APPLE_OPENGL_FRAMEWORK
+#if defined(HAVE_APPLE_OPENGL_FRAMEWORK) || defined(HAVE_OPENGL_GL_H)
 #include <OpenGL/gl.h>
 #else
 #include <GL/gl.h>
@@ -75,7 +75,7 @@ MenuGL::MenuGL()
 	menuText[ScreenSize]= _("s c r e e n    s i z e");
 	menuText[Sound]		= _("s o u n d    f x    v o l u m e");
 	menuText[Music]		= _("m u s i c    v o l u m e");
-	menuText[MouseSpeed]= _("m o u s e   s p e e d");
+	menuText[MovementSpeed]= _("m o v e m e n t   s p e e d");
 	menuText[Quit]		= _("q u i t");
 	
 	loadTextures();
@@ -160,7 +160,7 @@ static const char *skillString(int i)
 	switch(i)
 	{
 		case 2: return _("fish in a barrel");
-		case 3: return _("whimp");
+		case 3: return _("wimp");
 		case 4: return _("easy");
 		case 5: return _("normal");
 		case 6: return _("experienced");
@@ -477,15 +477,8 @@ void MenuGL::drawIndicator()
 			}
 			break;
 		case ScreenSize: 
-			level = (float)config->screenSize()/(float)MAX_SCREEN_SIZE; 
-			switch(config->screenSize())
-			{
-				case 0: sprintf(buf, _("512x384")); break;
-				case 1: sprintf(buf, _("640x480")); break;
-				case 2: sprintf(buf, _("800x600")); break;
-				case 3: sprintf(buf, _("1024x768")); break;
-				case 4: sprintf(buf, _("1280x960")); break;
-			}
+			level = (float)config->approxScreenSize()/(float)MAX_SCREEN_SIZE;
+			sprintf(buf, _("%dx%d"), config->screenW(), config->screenH());
 			break;
 		case FullScreen: 
 			level = (float)config->fullScreen(); 
@@ -500,8 +493,8 @@ void MenuGL::drawIndicator()
 			level = config->volMusic(); 
 			sprintf(buf, "%d", (int)((level+0.05)*10.0));	 
 			break;
-		case MouseSpeed: 
-			level = config->mouseSpeed()*10.0; 
+		case MovementSpeed:
+			level = config->movementSpeed()*10.0;
 			sprintf(buf, "%d", (int)((level+0.005)*100.0));	 
 			break;
 		default: 
@@ -807,7 +800,7 @@ void MenuGL::activateItem()
 			break;
 		case Music:
 			break;
-		case MouseSpeed:
+		case MovementSpeed:
 			break;
 		case Quit:
 			game->game_quit = true;
@@ -849,14 +842,14 @@ void MenuGL::incItem()
 			config->setGfxLevel(config->gfxLevel()+1);
 			break;
 		case ScreenSize:
-			config->setScreenSize(config->screenSize()+1);
+			config->setScreenSize(config->approxScreenSize()+1);
 			game->deleteTextures();
 			if( !game->toolkit->setVideoMode() )
 			{
 				mssgHelpOverride = true;
 				mssgAlpha = 1.1;
 				sprintf(mssgText, _("---- error setting screen size ----"));
-				config->setScreenSize(config->screenSize()-1);
+				config->setScreenSize(config->approxScreenSize()-1);
 			}
 			game->loadTextures();
 			break;
@@ -884,8 +877,8 @@ void MenuGL::incItem()
 			config->setVolMusic(config->volMusic()+0.05);
 			game->audio->setMusicVolume(config->volMusic());
 			break;
-		case MouseSpeed:
-			config->setMouseSpeed(config->mouseSpeed()+0.005);
+		case MovementSpeed:
+			config->setMovementSpeed(config->movementSpeed()+0.005);
 			break;
 		case Quit:
 			activateItem();
@@ -920,14 +913,14 @@ void MenuGL::decItem()
 			config->setGfxLevel(config->gfxLevel()-1);
 			break;
 		case ScreenSize:
-			config->setScreenSize(config->screenSize()-1);
+			config->setScreenSize(config->approxScreenSize()-1);
 			game->deleteTextures();
 			if( !game->toolkit->setVideoMode() )
 			{
 				mssgHelpOverride = true;
 				mssgAlpha = 1.1;
 				sprintf(mssgText, _("---- error setting screen size ----"));
-				config->setScreenSize(config->screenSize()+1);
+				config->setScreenSize(config->approxScreenSize()+1);
 			}
 			game->loadTextures();
 			break;
@@ -955,8 +948,8 @@ void MenuGL::decItem()
 			config->setVolMusic(config->volMusic()-0.05);
 			game->audio->setMusicVolume(config->volMusic());
 			break;
-		case MouseSpeed:
-			config->setMouseSpeed(config->mouseSpeed()-0.005);
+		case MovementSpeed:
+			config->setMovementSpeed(config->movementSpeed()-0.005);
 			break;
 		case Quit:
 			break;
