@@ -7,14 +7,14 @@
  */
 
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+#include <chromium-bsu-config.h>
 #endif
 
 #include "gettext.h"
 
 #include "compatibility.h"
 
-#ifdef HAVE_APPLE_OPENGL_FRAMEWORK
+#if defined(HAVE_APPLE_OPENGL_FRAMEWORK) || defined(HAVE_OPENGL_GL_H)
 #include <OpenGL/gl.h>
 #else
 #include <GL/gl.h>
@@ -170,6 +170,15 @@ const char* alterPathForPlatform(char* filename)
 			*walker =  ':';
 		walker++;
 	}
+#endif
+#ifdef _WIN32
+	char    *walker = filename;
+	while( *walker )
+	{
+		if(*walker == '/' )
+			*walker =  '\\';
+		walker++;
+	}
 #endif
 	return filename;
 }
